==> cljc.java-time-0.1.8.jar: public/js/test/js/cljs-runtime/shadow.util.js <==
goog.provide('shadow.util');
goog.require('cljs.core');
goog.require('cljs.core.async');
shadow.util.console_friendly = (function shadow$util$console_friendly(a){
if((a == null)){
return "nil";
} else {
if((a instanceof cljs.core.Keyword)){
return cljs.core.str.cljs$core$IFn$_invoke$arity$1(a);
} else {
if(typeof a === 'string'){
return a;
} else {
if(typeof a === 'number'){
return a;
} else {
if((((!((a == null))))?(((((a.cljs$lang$protocol_mask$partition0$ & (2147483648))) || ((cljs.core.PROTOCOL_SENTINEL === a.cljs$core$IPrintWithWriter$))))?true:(((!a.cljs$lang$protocol_mask$partition0$))?cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IPrintWithWriter,a):false)):cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IPrintWithWriter,a))){
return cljs.core.pr_str.call(null,a);
} else {
return a;

}
}
}
}
}
});
shadow.util.go_BANG_ = (function shadow$util$go_BANG_(var_args){
var args__4736__auto__ = [];
var len__4730__auto___46814 = arguments.length;
var i__4731__auto___46815 = (0);
while(true){
if((i__4731__auto___46815 < len__4730__auto___46814)){
args__4736__auto__.push((arguments[i__4731__auto___46815]));

var G__46816 = (i__4731__auto___46815 + (1));
i__4731__auto___46815 = G__46816;
continue;
} else {
}
break;
}

var argseq__4737__auto__ = ((((0) < args__4736__auto__.length))?(new cljs.core.IndexedSeq(args__4736__auto__.slice((0)),(0),null)):null);
return shadow.util.go_BANG_.cljs$core$IFn$_invoke$arity$variadic(argseq__4737__auto__);
});

shadow.util.go_BANG_.cljs$core$IFn$_invoke$arity$variadic = (function (body){
throw cljs.core.ex_info.call(null,"go! is a macro",cljs.core.PersistentArrayMap.EMPTY);
});

shadow.util.go_BANG_.cljs$lang$maxFixedArity = (0);

/** @this {Function} */
shadow.util.go_BANG_.cljs$lang$applyTo = (function (seq46764){
var self__4718__auto__ = this;
return self__4718__auto__.cljs$core$IFn$_invoke$arity$variadic(cljs.core.seq.call(null,seq46764));
});

shadow.util.console_QMARK_ = (typeof console !== 'undefined');
shadow.util.log = (function shadow$util$log(var_args){
var G__46781 = arguments.length;
switch (G__46781) {
case 1:
return shadow.util.log.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 2:
return shadow.util.log.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return shadow.util.log.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
case 4:
return shadow.util.log.cljs$core$IFn$_invoke$arity$4((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]));

break;
case 5:
return shadow.util.log.cljs$core$IFn$_invoke$arity$5((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]));

break;
case 6:
return shadow.util.log.cljs$core$IFn$_invoke$arity$6((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]));

break;
default:
var args_arr__4751__auto__ = [];
var len__4730__auto___46823 = arguments.length;
var i__4731__auto___46824 = (0);
while(true){
if((i__4731__auto___46824 < len__4730__auto___46823)){
args_arr__4751__auto__.push((arguments[i__4731__auto___46824]));

var G__46825 = (i__4731__auto___46824 + (1));
i__4731__auto___46824 = G__46825;
continue;
} else {
}
break;
}

var argseq__4752__auto__ = (new cljs.core.IndexedSeq(args_arr__4751__auto__.slice((6)),(0),null));
return shadow.util.log.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),argseq__4752__auto__);

}
});

shadow.util.log.cljs$core$IFn$_invoke$arity$1 = (function (a1){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1));
} else {
return null;
}
});

shadow.util.log.cljs$core$IFn$_invoke$arity$2 = (function (a1,a2){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2));
} else {
return null;
}
});

shadow.util.log.cljs$core$IFn$_invoke$arity$3 = (function (a1,a2,a3){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2),shadow.util.console_friendly.call(null,a3));
} else {
return null;
}
});

shadow.util.log.cljs$core$IFn$_invoke$arity$4 = (function (a1,a2,a3,a4){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2),shadow.util.console_friendly.call(null,a3),shadow.util.console_friendly.call(null,a4));
} else {
return null;
}
});

shadow.util.log.cljs$core$IFn$_invoke$arity$5 = (function (a1,a2,a3,a4,a5){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2),shadow.util.console_friendly.call(null,a3),shadow.util.console_friendly.call(null,a4),shadow.util.console_friendly.call(null,a5));
} else {
return null;
}
});

shadow.util.log.cljs$core$IFn$_invoke$arity$6 = (function (a1,a2,a3,a4,a5,a6){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2),shadow.util.console_friendly.call(null,a3),shadow.util.console_friendly.call(null,a4),shadow.util.console_friendly.call(null,a5),shadow.util.console_friendly.call(null,a6));
} else {
return null;
}
});

shadow.util.log.cljs$core$IFn$_invoke$arity$variadic = (function (a1,a2,a3,a4,a5,a6,more){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2),shadow.util.console_friendly.call(null,a3),shadow.util.console_friendly.call(null,a4),shadow.util.console_friendly.call(null,a5),shadow.util.console_friendly.call(null,a6),"more:",cljs.core.pr_str.call(null,more));
} else {
return null;
}
});

/** @this {Function} */
shadow.util.log.cljs$lang$applyTo = (function (seq46774){
var G__46775 = cljs.core.first.call(null,seq46774);
var seq46774__$1 = cljs.core.next.call(null,seq46774);
var G__46776 = cljs.core.first.call(null,seq46774__$1);
var seq46774__$2 = cljs.core.next.call(null,seq46774__$1);
var G__46777 = cljs.core.first.call(null,seq46774__$2);
var seq46774__$3 = cljs.core.next.call(null,seq46774__$2);
var G__46778 = cljs.core.first.call(null,seq46774__$3);
var seq46774__$4 = cljs.core.next.call(null,seq46774__$3);
var G__46779 = cljs.core.first.call(null,seq46774__$4);
var seq46774__$5 = cljs.core.next.call(null,seq46774__$4);
var G__46780 = cljs.core.first.call(null,seq46774__$5);
var seq46774__$6 = cljs.core.next.call(null,seq46774__$5);
var self__4717__auto__ = this;
return self__4717__auto__.cljs$core$IFn$_invoke$arity$variadic(G__46775,G__46776,G__46777,G__46778,G__46779,G__46780,seq46774__$6);
});

shadow.util.log.cljs$lang$maxFixedArity = (6);

shadow.util.remove_from_vector = (function shadow$util$remove_from_vector(coll,key){
return cljs.core.persistent_BANG_.call(null,cljs.core.reduce.call(null,(function (v,p__46804){
var vec__46805 = p__46804;
var idx = cljs.core.nth.call(null,vec__46805,(0),null);
var item = cljs.core.nth.call(null,vec__46805,(1),null);
if(cljs.core._EQ_.call(null,idx,key)){
return v;
} else {
return cljs.core.conj_BANG_.call(null,v,item);
}
}),cljs.core.transient$.call(null,cljs.core.PersistentVector.EMPTY),cljs.core.map_indexed.call(null,cljs.core.vector,coll)));
});
shadow.util.remove_item_from_coll = (function shadow$util$remove_item_from_coll(coll,key,value){
if((((!((coll == null))))?(((((coll.cljs$lang$protocol_mask$partition0$ & (16384))) || ((cljs.core.PROTOCOL_SENTINEL === coll.cljs$core$IVector$))))?true:(((!coll.cljs$lang$protocol_mask$partition0$))?cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IVector,coll):false)):cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IVector,coll))){
return shadow.util.remove_from_vector.call(null,coll,key);
} else {
if((((!((coll == null))))?(((((coll.cljs$lang$protocol_mask$partition0$ & (1024))) || ((cljs.core.PROTOCOL_SENTINEL === coll.cljs$core$IMap$))))?true:(((!coll.cljs$lang$protocol_mask$partition0$))?cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IMap,coll):false)):cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IMap,coll))){
return cljs.core.dissoc.call(null,coll,key);
} else {
if((((!((coll == null))))?(((((coll.cljs$lang$protocol_mask$partition0$ & (4096))) || ((cljs.core.PROTOCOL_SENTINEL === coll.cljs$core$ISet$))))?true:(((!coll.cljs$lang$protocol_mask$partition0$))?cljs.core.native_satisfies_QMARK_.call(null,cljs.core.ISet,coll):false)):cljs.core.native_satisfies_QMARK_.call(null,cljs.core.ISet,coll))){
return cljs.core.disj.call(null,coll,value);
} else {
throw cljs.core.ex_info.call(null,"unknown coll type",new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"coll","coll",1647737163),coll,new cljs.core.Keyword(null,"key","key",-1516042587),key,new cljs.core.Keyword(null,"value","value",305978217),value], null));

}
}
}
});

//# sourceMappingURL=shadow.util.js.map

==> cljc.java-time-0.1.11.jar: public/js/test/js/cljs-runtime/shadow.util.js <==
goog.provide('shadow.util');
goog.require('cljs.core');
goog.require('cljs.core.async');
shadow.util.console_friendly = (function shadow$util$console_friendly(a){
if((a == null)){
return "nil";
} else {
if((a instanceof cljs.core.Keyword)){
return cljs.core.str.cljs$core$IFn$_invoke$arity$1(a);
} else {
if(typeof a === 'string'){
return a;
} else {
if(typeof a === 'number'){
return a;
} else {
if((((!((a == null))))?(((((a.cljs$lang$protocol_mask$partition0$ & (2147483648))) || ((cljs.core.PROTOCOL_SENTINEL === a.cljs$core$IPrintWithWriter$))))?true:(((!a.cljs$lang$protocol_mask$partition0$))?cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IPrintWithWriter,a):false)):cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IPrintWithWriter,a))){
return cljs.core.pr_str.call(null,a);
} else {
return a;

}
}
}
}
}
});
shadow.util.go_BANG_ = (function shadow$util$go_BANG_(var_args){
var args__6930__auto__ = [];
var len__6920__auto___55986 = arguments.length;
var i__6921__auto___55987 = (0);
while(true){
if((i__6921__auto___55987 < len__6920__auto___55986)){
args__6930__auto__.push((arguments[i__6921__auto___55987]));

var G__55988 = (i__6921__auto___55987 + (1));
i__6921__auto___55987 = G__55988;
continue;
} else {
}
break;
}

var argseq__6931__auto__ = ((((0) < args__6930__auto__.length))?(new cljs.core.IndexedSeq(args__6930__auto__.slice((0)),(0),null)):null);
return shadow.util.go_BANG_.cljs$core$IFn$_invoke$arity$variadic(argseq__6931__auto__);
});

(shadow.util.go_BANG_.cljs$core$IFn$_invoke$arity$variadic = (function (body){
throw cljs.core.ex_info.call(null,"go! is a macro",cljs.core.PersistentArrayMap.EMPTY);
}));

(shadow.util.go_BANG_.cljs$lang$maxFixedArity = (0));

/** @this {Function} */
(shadow.util.go_BANG_.cljs$lang$applyTo = (function (seq55946){
var self__6906__auto__ = this;
return self__6906__auto__.cljs$core$IFn$_invoke$arity$variadic(cljs.core.seq.call(null,seq55946));
}));

shadow.util.console_QMARK_ = (typeof console !== 'undefined');
shadow.util.log = (function shadow$util$log(var_args){
var G__55965 = arguments.length;
switch (G__55965) {
case 1:
return shadow.util.log.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 2:
return shadow.util.log.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
case 3:
return shadow.util.log.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
case 4:
return shadow.util.log.cljs$core$IFn$_invoke$arity$4((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]));

break;
case 5:
return shadow.util.log.cljs$core$IFn$_invoke$arity$5((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]));

break;
case 6:
return shadow.util.log.cljs$core$IFn$_invoke$arity$6((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]));

break;
default:
var args_arr__6949__auto__ = [];
var len__6920__auto___55992 = arguments.length;
var i__6921__auto___55993 = (0);
while(true){
if((i__6921__auto___55993 < len__6920__auto___55992)){
args_arr__6949__auto__.push((arguments[i__6921__auto___55993]));

var G__55994 = (i__6921__auto___55993 + (1));
i__6921__auto___55993 = G__55994;
continue;
} else {
}
break;
}

var argseq__6950__auto__ = (new cljs.core.IndexedSeq(args_arr__6949__auto__.slice((6)),(0),null));
return shadow.util.log.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]),(arguments[(5)]),argseq__6950__auto__);

}
});

(shadow.util.log.cljs$core$IFn$_invoke$arity$1 = (function (a1){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1));
} else {
return null;
}
}));

(shadow.util.log.cljs$core$IFn$_invoke$arity$2 = (function (a1,a2){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2));
} else {
return null;
}
}));

(shadow.util.log.cljs$core$IFn$_invoke$arity$3 = (function (a1,a2,a3){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2),shadow.util.console_friendly.call(null,a3));
} else {
return null;
}
}));

(shadow.util.log.cljs$core$IFn$_invoke$arity$4 = (function (a1,a2,a3,a4){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2),shadow.util.console_friendly.call(null,a3),shadow.util.console_friendly.call(null,a4));
} else {
return null;
}
}));

(shadow.util.log.cljs$core$IFn$_invoke$arity$5 = (function (a1,a2,a3,a4,a5){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2),shadow.util.console_friendly.call(null,a3),shadow.util.console_friendly.call(null,a4),shadow.util.console_friendly.call(null,a5));
} else {
return null;
}
}));

(shadow.util.log.cljs$core$IFn$_invoke$arity$6 = (function (a1,a2,a3,a4,a5,a6){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2),shadow.util.console_friendly.call(null,a3),shadow.util.console_friendly.call(null,a4),shadow.util.console_friendly.call(null,a5),shadow.util.console_friendly.call(null,a6));
} else {
return null;
}
}));

(shadow.util.log.cljs$core$IFn$_invoke$arity$variadic = (function (a1,a2,a3,a4,a5,a6,more){
if(shadow.util.console_QMARK_){
return console.log(shadow.util.console_friendly.call(null,a1),shadow.util.console_friendly.call(null,a2),shadow.util.console_friendly.call(null,a3),shadow.util.console_friendly.call(null,a4),shadow.util.console_friendly.call(null,a5),shadow.util.console_friendly.call(null,a6),"more:",cljs.core.pr_str.call(null,more));
} else {
return null;
}
}));

/** @this {Function} */
(shadow.util.log.cljs$lang$applyTo = (function (seq55958){
var G__55959 = cljs.core.first.call(null,seq55958);
var seq55958__$1 = cljs.core.next.call(null,seq55958);
var G__55960 = cljs.core.first.call(null,seq55958__$1);
var seq55958__$2 = cljs.core.next.call(null,seq55958__$1);
var G__55961 = cljs.core.first.call(null,seq55958__$2);
var seq55958__$3 = cljs.core.next.call(null,seq55958__$2);
var G__55962 = cljs.core.first.call(null,seq55958__$3);
var seq55958__$4 = cljs.core.next.call(null,seq55958__$3);
var G__55963 = cljs.core.first.call(null,seq55958__$4);
var seq55958__$5 = cljs.core.next.call(null,seq55958__$4);
var G__55964 = cljs.core.first.call(null,seq55958__$5);
var seq55958__$6 = cljs.core.next.call(null,seq55958__$5);
var self__6905__auto__ = this;
return self__6905__auto__.cljs$core$IFn$_invoke$arity$variadic(G__55959,G__55960,G__55961,G__55962,G__55963,G__55964,seq55958__$6);
}));

(shadow.util.log.cljs$lang$maxFixedArity = (6));

shadow.util.remove_from_vector = (function shadow$util$remove_from_vector(coll,key){
return cljs.core.persistent_BANG_.call(null,cljs.core.reduce.call(null,(function (v,p__55977){
var vec__55978 = p__55977;
var idx = cljs.core.nth.call(null,vec__55978,(0),null);
var item = cljs.core.nth.call(null,vec__55978,(1),null);
if(cljs.core._EQ_.call(null,idx,key)){
return v;
} else {
return cljs.core.conj_BANG_.call(null,v,item);
}
}),cljs.core.transient$.call(null,cljs.core.PersistentVector.EMPTY),cljs.core.map_indexed.call(null,cljs.core.vector,coll)));
});
shadow.util.remove_item_from_coll = (function shadow$util$remove_item_from_coll(coll,key,value){
if((((!((coll == null))))?(((((coll.cljs$lang$protocol_mask$partition0$ & (16384))) || ((cljs.core.PROTOCOL_SENTINEL === coll.cljs$core$IVector$))))?true:(((!coll.cljs$lang$protocol_mask$partition0$))?cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IVector,coll):false)):cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IVector,coll))){
return shadow.util.remove_from_vector.call(null,coll,key);
} else {
if((((!((coll == null))))?(((((coll.cljs$lang$protocol_mask$partition0$ & (1024))) || ((cljs.core.PROTOCOL_SENTINEL === coll.cljs$core$IMap$))))?true:(((!coll.cljs$lang$protocol_mask$partition0$))?cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IMap,coll):false)):cljs.core.native_satisfies_QMARK_.call(null,cljs.core.IMap,coll))){
return cljs.core.dissoc.call(null,coll,key);
} else {
if((((!((coll == null))))?(((((coll.cljs$lang$protocol_mask$partition0$ & (4096))) || ((cljs.core.PROTOCOL_SENTINEL === coll.cljs$core$ISet$))))?true:(((!coll.cljs$lang$protocol_mask$partition0$))?cljs.core.native_satisfies_QMARK_.call(null,cljs.core.ISet,coll):false)):cljs.core.native_satisfies_QMARK_.call(null,cljs.core.ISet,coll))){
return cljs.core.disj.call(null,coll,value);
} else {
throw cljs.core.ex_info.call(null,"unknown coll type",new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"coll","coll",1647737163),coll,new cljs.core.Keyword(null,"key","key",-1516042587),key,new cljs.core.Keyword(null,"value","value",305978217),value], null));

}
}
}
});

//# sourceMappingURL=shadow.util.js.map
